@@ -2,7 +2,7 @@ from typing import Dict
 import json
 
 from azure.core import MatchConditions
-from azure.core.exceptions import ResourceExistsError, ResourceModifiedError
+from azure.core.exceptions import ResourceExistsError, ResourceModifiedError, ResourceNotFoundError
 from azure.storage.blob import ContainerClient
 from azure.identity import DefaultAzureCredential
 
@@ -39,21 +39,35 @@ class AzureBlobStorageProvider(StorageProvider):
         return False
 
     def download_data(self, key: str, etag: str) -> bytes:
+        args = dict(blob=key)
+        if etag is not None:
+            args.update(
+                dict(
+                    etag=etag,
+                    match_condition=MatchConditions.IfNotModified,
+                )
+            )
         try:
-            return self._container_client.download_blob(
-                blob=key,
-                etag=etag,
-                match_condition=MatchConditions.IfNotModified if etag is not None else None,
-            ).readall()
+            return self._container_client.download_blob(**args).readall()
         except ResourceModifiedError as e:
             self.raise_key_sync_error(key=key, etag=etag, inner_exception=e)
+        except ResourceNotFoundError as e:
+            if etag is None:
+                return None
+            self.raise_key_sync_error(key=key, etag=etag, inner_exception=e)
 
     def upload_data(self, key: str, etag: str, data: bytes) -> str:
+        if not isinstance(data, bytes):
+            raise ValueError("Data must be bytes like")
         expecting_blob = etag is not None
-        args = {"overwrite": expecting_blob}
+        args = dict(overwrite=expecting_blob)
         if expecting_blob:
-            args["etag"] = etag
-            args["match_condition"] = MatchConditions.IfNotModified
+            args.update(
+                dict(
+                    etag=etag,
+                    match_condition=MatchConditions.IfNotModified,
+                )
+            )
         bc = self._container_client.get_blob_client(blob=key)
         try:
             response = bc.upload_blob(
